@@ -314,7 +314,7 @@ def main_prg():
     }
 
     # use live or test ids
-    URL, KEY, SECRET = URLS[args.live]
+    URL = URLS[args.live]
 
     _ = get_bucketed_trades(url=f"{URL}{args.entryPoint}", Q=query, **kwargs)
     return None
